aiscalator package
==================

Subpackages
-----------

.. toctree::

    aiscalator.airflow
    aiscalator.core
    aiscalator.jupyter

Submodules
----------

aiscalator.api module
---------------------

.. automodule:: aiscalator.api
    :members:
    :undoc-members:
    :show-inheritance:

aiscalator.cli module
---------------------

.. automodule:: aiscalator.cli
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: aiscalator
    :members:
    :undoc-members:
    :show-inheritance:
